"""
Usage:
  kontol <command> [<args>...]

Options:
  -h, --help                             display this help and exit
  -v, --version                          Print version information and quit

Commands:
  masukin           Run Your Project

Run 'kontol COMMAND --help' for more information on a command.
"""

from inspect import getmembers, isclass
from docopt import docopt, DocoptExit
from kontol import __version__ as VERSION


def main():
    """Main CLI entrypoint."""
    import kontol.clis
    options = docopt(__doc__, version=VERSION, options_first=True)
    command_name = ""
    args = ""
    command_class =""

    command_name = options.pop('<command>')
    args = options.pop('<args>')

    if args is None:
        args = {}

    try:
        module = getattr(kontol.clis, command_name)
        kontol.clis = getmembers(module, isclass)
        command_class = [command[1] for command in kontol.clis
                   if command[0] != 'Base'][0]
    except AttributeError as e:
        print(e)
        raise DocoptExit()

    command = command_class(options, args)
    command.execute()


if __name__ == '__main__':
    main()



from docopt import docopt


class Base(object):
    """Base class for the commands"""

    def __init__(self, options, command_args):
        """
        Initialize the commands.

        :param command_args: arguments of the command
        """
        self.options = options
        self.args = docopt(self.__doc__, argv=command_args)

    def execute(self):
        """Execute the commands"""

        raise NotImplementedError